# mt5proxy

mt5proxy --users admin=123456,admin2=123

http://127.0.0.1:8082/get_symbols

http://127.0.0.1:8082/copy_rates_from?symbol=AUDUSD&time_frame=H4&date_from=20240116120000&count=10

http://127.0.0.1:8082/copy_rates_range?symbol=USDCNH&time_frame=H1&date_from=20250110120000&date_to=20250117120000

